@@ -48,7 +48,7 @@ class telegram:
                 self.logger.current_time(*items, level=level)
             else:
                 self.logger.log(*items, level=level)
-            self.logger(level=level)
+            self.logger.log(level=level)
         elif level != 'debug': # Don't print debug only messages
             print(*items)
             print()
\ No newline at end of file
